@@ -12,7 +12,7 @@ use Sub::Util    ();
 
 use experimental 'signatures';
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 # The main entity registry, inspired by https://github.com/skypjack/entt
 
@@ -314,12 +314,14 @@ sub sort ( $self, $name, $comparator ) {
 
     # See https://skypjack.github.io/2019-09-25-ecs-baf-part-5/
     my $caller = caller;
-    @$dense = sort {
+    {
         no strict 'refs';
-        local ${ $caller . '::a' } = $comps->[ $sparse->[ $a ] ];
-        local ${ $caller . '::b' } = $comps->[ $sparse->[ $b ] ];
-        $comparator->()
-    } @$dense;
+        @$dense = sort {
+            local ${ $caller . '::a' } = $comps->[ $sparse->[ $a ] ];
+            local ${ $caller . '::b' } = $comps->[ $sparse->[ $b ] ];
+            $comparator->();
+        } @$dense;
+    }
 
     for my $curr ( 0 .. $#$dense ) {
         my $next = $sparse->[ $dense->[ $curr ] ];
